<?php

namespace Bixo\Campaign\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Bixo\Campaign\Http\Requests\CampaignCallRequest;
use Bixo\Campaign\Interfaces\CampaignCallRepositoryInterface;
use Bixo\Campaign\Models\CampaignCall;

/**
 * Resource controller class for campaign_call.
 */
class CampaignCallResourceController extends BaseController
{

    /**
     * Initialize campaign_call resource controller.
     *
     * @param type CampaignCallRepositoryInterface $campaign_call
     *
     * @return null
     */
    public function __construct(CampaignCallRepositoryInterface $campaign_call)
    {
        parent::__construct();
        $this->repository = $campaign_call;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Campaign\Repositories\Criteria\CampaignCallResourceCriteria::class);
    }

    /**
     * Display a list of campaign_call.
     *
     * @return Response
     */
    public function index(CampaignCallRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Bixo\Campaign\Repositories\Presenter\CampaignCallPresenter::class)
                ->$function();
        }

        $campaign_calls = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('campaign::campaign_call.names'))
            ->view('campaign::campaign_call.index', true)
            ->data(compact('campaign_calls', 'view'))
            ->output();
    }

    /**
     * Display campaign_call.
     *
     * @param Request $request
     * @param Model   $campaign_call
     *
     * @return Response
     */
    public function show(CampaignCallRequest $request, CampaignCall $campaign_call)
    {

        if ($campaign_call->exists) {
            $view = 'campaign::campaign_call.show';
        } else {
            $view = 'campaign::campaign_call.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('campaign::campaign_call.name'))
            ->data(compact('campaign_call'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new campaign_call.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CampaignCallRequest $request)
    {

        $campaign_call = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('campaign::campaign_call.name')) 
            ->view('campaign::campaign_call.create', true) 
            ->data(compact('campaign_call'))
            ->output();
    }

    /**
     * Create new campaign_call.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CampaignCallRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $campaign_call                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('campaign::campaign_call.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('campaign/campaign_call/' . $campaign_call->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/campaign/campaign_call'))
                ->redirect();
        }

    }

    /**
     * Show campaign_call for editing.
     *
     * @param Request $request
     * @param Model   $campaign_call
     *
     * @return Response
     */
    public function edit(CampaignCallRequest $request, CampaignCall $campaign_call)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('campaign::campaign_call.name'))
            ->view('campaign::campaign_call.edit', true)
            ->data(compact('campaign_call'))
            ->output();
    }

    /**
     * Update the campaign_call.
     *
     * @param Request $request
     * @param Model   $campaign_call
     *
     * @return Response
     */
    public function update(CampaignCallRequest $request, CampaignCall $campaign_call)
    {
        try {
            $attributes = $request->all();

            $campaign_call->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('campaign::campaign_call.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('campaign/campaign_call/' . $campaign_call->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('campaign/campaign_call/' . $campaign_call->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the campaign_call.
     *
     * @param Model   $campaign_call
     *
     * @return Response
     */
    public function destroy(CampaignCallRequest $request, CampaignCall $campaign_call)
    {
        try {

            $campaign_call->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('campaign::campaign_call.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('campaign/campaign_call/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('campaign/campaign_call/' . $campaign_call->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple campaign_call.
     *
     * @param Model   $campaign_call
     *
     * @return Response
     */
    public function delete(CampaignCallRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('campaign::campaign_call.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('campaign/campaign_call'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/campaign/campaign_call'))
                ->redirect();
        }

    }

    /**
     * Restore deleted campaign_calls.
     *
     * @param Model   $campaign_call
     *
     * @return Response
     */
    public function restore(CampaignCallRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('campaign::campaign_call.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/campaign/campaign_call'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/campaign/campaign_call/'))
                ->redirect();
        }

    }

}
